@@ -52,7 +52,7 @@ test_that("GitHub Action CI setup works", {
     root = getwd(),
     open = FALSE, verbose = FALSE
   )
-  expect_error(use_ci("stuff"), "must be one of")
+  expect_error(use_ci("stuff", root = getwd()), "must be one of")
   use_ci("gha", root = getwd())
   expect_true(file_exists(".github/workflows/pre-commit.yaml"))
 })
@@ -82,40 +82,3 @@ test_that("Pre-commit CI setup works", {
   )
   expect_error(use_ci(root = getwd(), open = FALSE), "o `.pre-commit-config.yaml`")
 })
-
-
-test_that("Autoupdate is not conducted when renv present in incompatible setup", {
-  skip_on_cran()
-
-  # mock old pre-commit and renv versions
-  mockery::stub(ensure_renv_precommit_compat, "version_precommit", "2.13.0")
-
-  local_test_setup(
-    git = TRUE, use_precommit = TRUE, install_hooks = FALSE, open = FALSE
-  )
-  initial <- rev_read() %>%
-    rev_as_pkg_version()
-  # simulate adding {renv}
-  writeLines("", "renv.lock")
-
-  # should downgrade rev
-  expect_error(
-    ensure_renv_precommit_compat(
-      package_version_renv = package_version("0.13.0"), root = getwd()
-    ),
-    "Please update"
-  )
-  downgraded <- rev_read() %>%
-    rev_as_pkg_version()
-  expect_true(downgraded == initial)
-
-  # simulate removing {renv} should be updated
-  fs::file_delete("renv.lock")
-  expect_warning(
-    ensure_renv_precommit_compat(
-      package_version("0.13.0"),
-      root = getwd()
-    ),
-    NA
-  )
-})
